@@ -26,6 +26,7 @@
 #include "goaprovider-priv.h"
 #include "goaoauth2provider.h"
 #include "goafacebookprovider.h"
+#include "goaobjectskeletonutils.h"
 
 /**
  * GoaFacebookProvider:
@@ -321,8 +322,6 @@ build_object (GoaProvider         *provider,
               GError             **error)
 {
   GoaAccount *account;
-  GoaPhotos *photos = NULL;
-  GoaMaps *maps = NULL;
   gboolean photos_enabled;
   gboolean maps_enabled;
   gboolean ret = FALSE;
@@ -342,22 +341,8 @@ build_object (GoaProvider         *provider,
   account = goa_object_get_account (GOA_OBJECT (object));
 
   /* Photos */
-  photos = goa_object_get_photos (GOA_OBJECT (object));
   photos_enabled = g_key_file_get_boolean (key_file, group, "PhotosEnabled", NULL);
-
-  if (photos_enabled)
-    {
-      if (photos == NULL)
-        {
-          photos = goa_photos_skeleton_new ();
-          goa_object_skeleton_set_photos (object, photos);
-        }
-    }
-  else
-    {
-      if (photos != NULL)
-        goa_object_skeleton_set_photos (object, NULL);
-    }
+  goa_object_skeleton_attach_photos (object, photos_enabled);
 
   if (just_added)
     {
@@ -370,22 +355,8 @@ build_object (GoaProvider         *provider,
     }
 
   /* Maps */
-  maps = goa_object_get_maps (GOA_OBJECT (object));
   maps_enabled = g_key_file_get_boolean (key_file, group, "MapsEnabled", NULL);
-
-  if (maps_enabled)
-    {
-      if (maps == NULL)
-        {
-          maps = goa_maps_skeleton_new ();
-          goa_object_skeleton_set_maps (object, maps);
-        }
-    }
-  else
-    {
-      if (maps != NULL)
-        goa_object_skeleton_set_maps (object, NULL);
-    }
+  goa_object_skeleton_attach_maps (object, maps_enabled);
 
   if (just_added)
     {
@@ -400,8 +371,6 @@ build_object (GoaProvider         *provider,
 
  out:
   g_clear_object (&account);
-  g_clear_object (&photos);
-  g_clear_object (&maps);
   return ret;
 }
 
