@@ -26,6 +26,7 @@
 #include "goaprovider.h"
 #include "goaprovider-priv.h"
 #include "goatelepathyprovider.h"
+#include "goaobjectskeletonutils.h"
 #include "goautils.h"
 
 typedef struct _GoaTelepathyProviderPrivate GoaTelepathyProviderPrivate;
@@ -408,8 +409,8 @@ add_account (GoaProvider  *provider,
   AddAccountData data;
   TpawAccountSettings *settings = NULL;
   TpawAccountWidget *account_widget = NULL;
-  GtkRequisition req;
   gint response;
+  gint width;
 
   settings = tpaw_protocol_create_account_settings (priv->protocol);
   if (settings == NULL)
@@ -447,8 +448,8 @@ add_account (GoaProvider  *provider,
   /* The dialog now contains a lot of empty space between the account widget
    * and the buttons. We force it's vertical size to be just right to fit the
    * widget. */
-  gtk_widget_get_preferred_size (GTK_WIDGET (dialog), NULL, &req);
-  gtk_widget_set_size_request (GTK_WIDGET (dialog), req.width, 1);
+  gtk_window_get_size (GTK_WINDOW (dialog), &width, NULL);
+  gtk_window_set_default_size (GTK_WINDOW (dialog), width, -1);
 
   response = gtk_dialog_run (GTK_DIALOG (dialog));
   if (response != GTK_RESPONSE_OK && response != GTK_RESPONSE_APPLY)
@@ -711,12 +712,10 @@ build_object (GoaProvider        *provider,
               GError            **error)
 {
   GoaAccount *account;
-  GoaChat *chat;
   gboolean chat_enabled;
   gboolean ret;
 
   account = NULL;
-  chat = NULL;
   ret = FALSE;
 
   /* Chain up */
@@ -732,21 +731,8 @@ build_object (GoaProvider        *provider,
   account = goa_object_get_account (GOA_OBJECT (object));
 
   /* Chat */
-  chat = goa_object_get_chat (GOA_OBJECT (object));
   chat_enabled = g_key_file_get_boolean (key_file, group, "ChatEnabled", NULL);
-  if (chat_enabled)
-    {
-      if (chat == NULL)
-        {
-          chat = goa_chat_skeleton_new ();
-          goa_object_skeleton_set_chat (object, chat);
-        }
-    }
-  else
-    {
-      if (chat != NULL)
-        goa_object_skeleton_set_chat (object, NULL);
-    }
+  goa_object_skeleton_attach_chat (object, chat_enabled);
 
   if (just_added)
     {
@@ -760,7 +746,6 @@ build_object (GoaProvider        *provider,
   ret = TRUE;
 
 out:
-  g_clear_object (&chat);
   g_clear_object (&account);
   return ret;
 }
